diff --git a/core/tests/Drupal/TestTools/TestVarDumper.php b/core/tests/Drupal/TestTools/TestVarDumper.php
index 67d6136e155f909be5c0ed6f8e5f47af283cda39..dbf5af90f971807d885bfc0ba82bfbc2fcb333bc 100644
--- a/core/tests/Drupal/TestTools/TestVarDumper.php
+++ b/core/tests/Drupal/TestTools/TestVarDumper.php
@@ -22,7 +22,7 @@ class TestVarDumper {
   public static function cliHandler($var) {
     $cloner = new VarCloner();
     $dumper = new CliDumper();
-    fwrite(STDOUT, "\n");
+    fwrite(STDERR, "\n");
     $dumper->setColors(TRUE);
     $dumper->dump(
       $cloner->cloneVar($var),
@@ -30,7 +30,7 @@ function ($line, $depth, $indent_pad) {
         // A negative depth means "end of dump".
         if ($depth >= 0) {
           // Adds a two spaces indentation to the line.
-          fwrite(STDOUT, str_repeat($indent_pad, $depth) . $line . "\n");
+          fwrite(STDERR, str_repeat($indent_pad, $depth) . $line . "\n");
         }
       }
     );
diff --git a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
index 649b4d0476273904fc2a55da2b9502ac156d561d..301aaa43cee326f62e7ad110df2c927346fa0ebd 100644
--- a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
+++ b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
@@ -601,11 +601,11 @@ public function testDeprecationHeaders() {
    * Tests the dump() function provided by the var-dumper Symfony component.
    */
   public function testVarDump() {
     // Append the stream capturer to the STDOUT stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
     stream_filter_register("capture", StreamCapturer::class);
-    stream_filter_append(STDOUT, "capture");
+    stream_filter_append(STDERR, "capture");
 
     // Dump some variables to check that dump() in test code produces output
     // on the command line that is running the test.
@@ -601,11 +601,11 @@ public function testDeprecationHeaders() {
    */
   public function testVarDump() {
-    // Append the stream capturer to the STDOUT stream, so that we can test the
+    // Append the stream capturer to the STDERR stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
diff --git a/core/tests/Drupal/KernelTests/KernelTestBaseTest.php b/core/tests/Drupal/KernelTests/KernelTestBaseTest.php
index ce5e37aef9572b736f06e8642d943627cdded847..2f97a77a4ec99b919a8c61851b9a921a26ff5551 100644
--- a/core/tests/Drupal/KernelTests/KernelTestBaseTest.php
+++ b/core/tests/Drupal/KernelTests/KernelTestBaseTest.php
@@ -313,11 +313,11 @@ public function testProfileModules() {
    * Tests the dump() function provided by the var-dumper Symfony component.
    */
   public function testVarDump() {
     // Append the stream capturer to the STDOUT stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
     stream_filter_register("capture", StreamCapturer::class);
-    stream_filter_append(STDOUT, "capture");
+    stream_filter_append(STDERR, "capture");
 
     // Dump some variables.
     $this->enableModules(['system', 'user']);
@@ -313,11 +313,11 @@ public function testProfileModules() {
    */
   public function testVarDump() {
-    // Append the stream capturer to the STDOUT stream, so that we can test the
+    // Append the stream capturer to the STDERR stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
diff --git a/core/tests/Drupal/Tests/UnitTestCaseTest.php b/core/tests/Drupal/Tests/UnitTestCaseTest.php
index 4d5a7948a87742d7fabaa7acf13e2383a2438dd9..033923cf1c4b760f769a5ffeede977caa43da3ae 100644
--- a/core/tests/Drupal/Tests/UnitTestCaseTest.php
+++ b/core/tests/Drupal/Tests/UnitTestCaseTest.php
@@ -17,11 +17,11 @@ class UnitTestCaseTest extends UnitTestCase {
    * Tests the dump() function in a test run in the same process.
    */
   public function testVarDumpSameProcess() {
     // Append the stream capturer to the STDOUT stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
     stream_filter_register("capture", StreamCapturer::class);
-    stream_filter_append(STDOUT, "capture");
+    stream_filter_append(STDERR, "capture");
 
     // Dump some variables.
     $object = (object) [
@@ -40,11 +40,11 @@ public function testVarDumpSameProcess() {
    * @runInSeparateProcess
    */
   public function testVarDumpSeparateProcess() {
     // Append the stream capturer to the STDOUT stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
     stream_filter_register("capture", StreamCapturer::class);
-    stream_filter_append(STDOUT, "capture");
+    stream_filter_append(STDERR, "capture");
 
     // Dump some variables.
     $object = (object) [
@@ -17,11 +17,11 @@ class UnitTestCaseTest extends UnitTestCase {
    */
   public function testVarDumpSameProcess() {
-    // Append the stream capturer to the STDOUT stream, so that we can test the
+    // Append the stream capturer to the STDERR stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.
@@ -40,11 +40,11 @@ public function testVarDumpSameProcess() {
    */
   public function testVarDumpSeparateProcess() {
-    // Append the stream capturer to the STDOUT stream, so that we can test the
+    // Append the stream capturer to the STDERR stream, so that we can test the
     // dump() output and also prevent it from actually outputting in this
     // particular test.